;
window.W = window.W || {};


;
(function (undefined) {
    'use strict';

    W.UserModel = Backbone.Model.extend({
        urlRoot: '/rest-auth/user/',

        defaults: {
            username: ""
        },

        url: function () {
            var original_url = Backbone.Model.prototype.url.call(this);
            var parsed_url = original_url + (original_url.charAt(original_url.length - 1) == '/' ? '' : '/');

            return parsed_url;
        },
    });


    W.AttachmentModel = Backbone.RelationalModel.extend({
        defaults: {
            id: null,
            url: "",
            title: "",
            attachment: null
        },

        urlRoot: '/api/attachments/',

        url: function () {
            var original_url = Backbone.Model.prototype.url.call(this);
            var parsed_url = original_url + (original_url.charAt(original_url.length - 1) == '/' ? '' : '/');

            return parsed_url;
        },

    })

    W.ScoreModel = Backbone.RelationalModel.extend({
        defaults: {
            title: "Untitled",
            mainline: {},
            stage_set: "Here comes the initial set",
            setting: '',
            duration: '',
            genre: '',
            tags: '',
            score_type: 1,
            score_author: "",
            performance_author: "",
            presentation: "",
            effectif: "",
            language: "",
        },

        urlRoot: '/api/scores/',

        url: function () {
            var original_url = Backbone.Model.prototype.url.call(this);
            var parsed_url = original_url + (original_url.charAt(original_url.length - 1) == '/' ? '' : '/');

            return parsed_url;
        },

        relations: [{
            type: Backbone.HasOne,
            key: 'mainline',
            relatedModel: 'LineModel',
            reverseRelation: {
                key: 'score',
                includeInJSON: false,
                type: Backbone.HasOne
            }
        }],

        getDepth: function () {
            // Methode pour le vue "slider"
            // based on http://stackoverflow.com/questions/13523951/how-to-check-the-depth-of-an-object

            var depthOf = function (object) {
                var level = 1;

                if (object.hasOwnProperty("sublines")) {
                    for (var line in object.sublines) {
                        var depth = depthOf(object.sublines[line]) + 1;
                        level = Math.max(depth, level);
                    }
                }

                return level
            };

            var json = this.toJSON();

            return depthOf(json.mainline || json.sublines);
        },

        parse: function (data) {
            function trimStrings(v) {
                if (typeof v === "string") {
                    return v.trim();
                } else if (typeof v === "number") {
                    return v;
                } else if (v === null) {
                    return v;
                } else if (Array.isArray(v)) {
                    return _.map(v, trimStrings);
                } else if (typeof v === "object") {
                    return _.mapObject(v, trimStrings);
                }

                return v;
            }

            // console.log(data);
            data = trimStrings(data);
            // console.log(data);
            return data;
        },
    });


    W.LineModel = Backbone.RelationalModel.extend({
        defaults: {
            sublines: [],
            //id:1, //il faudra mettre une id quand le modele sera opérationnel -> backend
            title: 'Sans titre', //(uniq)
            contingent: false, // optionnel, au choix de l'interprète
            module_: false,
            aspect: '',
            //choix dans un array (duratif, itératif, sémelfactif)
            // duratif, l'action se déroule en continu
            // itératif, l'action est répétitive
            // sémelfactif l'action est ponctuelle
            piece_jointe: '', //url qui pointe vers un document
            terme: '', //(str)
            attachment: null,
            // boucle: on teste d'abord si boucle check est true
            // si oui y a t'il une durée de n à p
            // si non mettre n et p à 0
            // TODO: check if those 4 props can be merge in one

            // rangeType = enum{undetermined, exact, minimal, range}
            // null | { type: rangeType, value: null|number|[number, number]}
            boucle: null,

            // TODO: check if those 3 props can be merge in one
            // alternativeMode = enum { inclusive, exclusive}
            // null | { type: rangeType, mode: alternativeMode, value: null|number|[number, number]}
            alternative: null,
            // alternative_mode: '', //choix dans un array (exclusive, inclusive, conditionnelle) Validation importante des conditions dans une boucle inclusive
            // alternative_symbole: '',

            condition: '', // seulement valide si axe contingent ou si sous-axe d'une alternative
            imperative: false,
            tag: '', //Validation: peut avoir un tag seulement si l'axe n'est pas principal, de plus le tag doit être le même pour ses siblings. Succession ordonnée, sans ordre, simultaméité, accumulation
            goto: null, //reference de l'axe vers lequel il renvoie
            focused: 0, // pas sûr que c'est l'endroit où mettre ceci.
            // Pas vraiment une propriété de l'objet.
            // Si l'objet est focused, il faut que la classe axis-focus
            // soit sur ses éléments handle et options.
            parent: null,
            actant: '', // string
            adresse: '', // string
            commandement: '', // string
            destination: '', // string
            code: '', // string
            indications: '' // long string
        },

        validate: function (attrs) {
            // TODO: bidon, à supprimer
            if (attrs.id > 3) {
                return 'Mauvais id.';
            }
        },

        getLevel: function () {
            var parent = this.get('parent');

            if (parent && parent.getLevel) {
                return parent.getLevel() + 1;
            }

            return 1;
        },

        addSubLine: function () {
            var sublines = this.get('sublines');
            var title = "Sous axe " + (sublines.length + 1);
            var tag = (sublines.length > 0) ? sublines[0] : W.tags[0];
            sublines.add({ title: title, tag: tag });
        },

        relations: [{
            type: Backbone.HasMany,
            key: 'sublines',
            // relatedModel: 'LineModel',
            collectionType: 'LineCollection',
            reverseRelation: {
                key: 'parent',
                includeInJSON: false
            },
        },
        {
            type: Backbone.HasOne,
            key: 'attachment',
            relatedModel: W.AttachmentModel
        }]
    });
})();
